<?php
/**
 * Extended object handlers
 *
 * For backward compat
 *
 * @copyright       The XOOPS project http://sourceforge.net/projects/xoops/
 * @license         http://www.fsf.org/copyleft/gpl.html GNU public license
 * @author          Taiwen Jiang <phppp@users.sourceforge.net>
 * @since           1.00
 * @version         $Id: object.php 1901 2008-07-26 04:05:57Z phppp $
 * @package         Frameworks
 * @subpackage      art
 */

if (!class_exists("ArtObject")):

/**
 * Art Object
 * 
 * @author D.J. (phppp)
 * @copyright copyright &copy; 2005 XoopsForge.com
 * @package module::article
 *
 * {@link XoopsObject} 
 **/

class ArtObject extends XoopsObject
{
    /**
     * @var string
     */
    var $plugin_path;
    
    /**
     * dynamically register additional filter for the object
     * 
     * This is from the original code along with /kernel/object.php,
     * It is not necessary but keep as it is, to change when necessary
     *
     * @param string $filtername name of the filter
     * @access public
     */
    function registerFilter($filtername)
    {
        parent::registerFilter($filtername);
    }

    /**
     * load all additional filters that have been registered to the object
     * 
     * This is from the original code along with /kernel/object.php,
     * I don't understand its design purpose in terms of plugin distribution but just leave as it is
     *
     * @access private
     */
    function _loadFilters()
    {
        static $loaded;
        if (!isset($loaded)) return;
        $loaded = 1;
        
        $path = empty($this->plugin_path) ? dirname(__FILE__).'/filters' : $this->plugin_path;
        @include_once $path.'/filter.php';
        foreach ($this->_filters as $f) {
            @include_once $path.'/'.strtolower($f).'php';
        }
    }
    
    /**
     * load all local filters for the object
     * 
     * Filter distribution:
     * In each module folder there is a folder "filter" containing filter files with, 
     * filename: [name of target class][.][function/action name][.php];
     * function name: [name of target class][_][function/action name];
     * parameter: the target object
     *
     * @param   string     $class    class name
     * @param   string     $method    function or action name
     * @access public
     */
    function loadFilters($method)
    {
        $this->_loadFilters();
        
        load_functions("filter");
        mod_loadFilters($this, $method);
    }

    /**
    * unset variable(s) for the object
    * 
    * @access public
    * @param mixed $var
    */
    function destoryVars($var)
    {
        if (empty($var)) return true;
        if (!is_array($var)) $var = array($var);
        foreach ($var as $key) {
            if (!isset($this->vars[$key])) continue;
            $this->vars[$key]["changed"] = null;
        }
        return true;
    }

}

/**
* object handler class.  
* @package module::article
*
* @author  D.J. (phppp)
* @copyright copyright &copy; 2000 The XOOPS Project
*
* {@link XoopsPersistableObjectHandler} 
*
*/

class ArtObjectHandler extends XoopsPersistableObjectHandler
{
    
    /**
     * Constructor
     *
     * @param object $db reference to the {@link XoopsDatabase} object     
     **/
    function ArtObjectHandler(&$db, $table = "", $className = "", $keyName = "", $identifierName = false) {
        $this->XoopsPersistableObjectHandler( $db, $table, $className, $keyName, $identifierName );
    }
        
    /**
     * get MySQL server version
     * 
     * @return     string
     */
    function mysql_server_version($conn = null)
    {
        if (!is_null($conn)) {
            return mysql_get_server_info($conn);
        } else {
            return mysql_get_server_info();
        }
    }
    
    /**
     * get MySQL major version
     * 
     * @return     integer    : 3 - 4.1-; 4 - 4.1+; 5 - 5.0+
     */
    function mysql_major_version()
    {
        $version = $this->mysql_server_version();
        if (version_compare( $version, "5.0.0", "ge" ) ) $mysql_version = 5;
        elseif (version_compare( $version, "4.1.0", "ge" ) ) $mysql_version = 4;
        else $mysql_version = 3;
        return $mysql_version;
    }

    function insert(&$object, $force = true)
    {
        if ($ret = parent::insert($object, $force)) {
            $object->unsetNew();
        }
        return $ret;
    }
}
endif;
?>